import machine
from umqttsimple import MQTTClient
import time
import ubinascii
# from machine import WDT
import network
import os
import config



print("Hello")
resetCause = machine.reset_cause()

# wdt = WDT(timeout=8000)
# wdt.feed()
# print("Watchdog enabled")

try:
    wlan = network.WLAN(network.STA_IF)
    wlan.active(True)
    wlan.connect(config.SSID, config.WPA_KEY)

    connectCnt = 0
    while (not wlan.isconnected() or (connectCnt > config.MAX_CONNECT_RETRY_CNT)):
        print("Not yet connected")
        # wdt.feed()
        connectCnt += 1
        time.sleep(1)

    if (not wlan.isconnected()):
        print("Failed to connect to wlan, restarting")
        machine.reset()

    print(f"Connected to WLAN: {resetCause} {connectCnt} {wlan.ifconfig()}")
    # wdt.feed()

    clientId = f"rpipwtherm-{ubinascii.hexlify(machine.unique_id())}"
    client = MQTTClient(clientId, config.MQTT_SERVER, keepalive=60, 
        ssl=True, user=config.MQTT_LOGIN, password=config.MQTT_PASSWORD)
    client.connect()
    print(f"Connected to MQTT broker {config.MQTT_SERVER} ")
    # wdt.feed()

    client.publish(config.STARTUP_TOPIC, f"Hello, rpipw thermometer is alive now at {wlan.ifconfig()}")
except Exception as e:
    print(f"Some error when starting: {e.__class__.__name__}, {e}")
    time.sleep(15)
    machine.reset()


try:
    client.publish(config.PAYLOAD_TOPIC, f"measurement")
    print("Payload sent")
    # wdt.feed()

    client.disconnect()
    print("Disconnected from broker")
    time.sleep(1)
    wlan.disconnect()
    wlan.active(False)
    print("Disconnected from network")
except Exception as e:
    print(f"Error in main loop: {e.__class__.__name__}, {e}")
finally:
    print("Waiting ...")
    # wdt.feed()

    time.sleep(config.MAIN_PERIOD_S)
    print("Restarting")
    time.sleep(1)
    machine.reset()

